@@ -26,7 +26,6 @@
 import socket
 from struct import pack
 from platform import system
-from sys import exc_info
 from time import sleep
 from random import choice
 from datetime import datetime
@@ -130,19 +129,22 @@ class BaseStrategy(object):
                         self.connection.server.current_address = candidate_address
                         self.connection.server.update_availability(candidate_address, True)
                         break
-                    except Exception:
+                    except Exception as e:
                         self.connection.server.update_availability(candidate_address, False)
-                        exception_history.append((datetime.now(), exc_info()[0], exc_info()[1], candidate_address[4]))
-
+                        # exception_history.append((datetime.now(), exc_type, exc_value, candidate_address[4]))
+                        exception_history.append((type(e)(str(e)), candidate_address[4]))
                 if not self.connection.server.current_address and exception_history:
-                    if len(exception_history) == 1:  # only one exception, reraise
-                        if log_enabled(ERROR):
-                            log(ERROR, '<%s> for <%s>', exception_history[0][1](exception_history[0][2]), self.connection)
-                        raise exception_history[0][1](exception_history[0][2])
-                    else:
-                        if log_enabled(ERROR):
-                            log(ERROR, 'unable to open socket for <%s>', self.connection)
-                        raise LDAPSocketOpenError('unable to open socket', exception_history)
+                    # if len(exception_history) == 1:  # only one exception, reraise
+                    #     if log_enabled(ERROR):
+                    #         log(ERROR, '<%s> for <%s>', exception_history[0][1](exception_history[0][2]), self.connection)
+                    #     raise exception_history[0][1](exception_history[0][2])
+                    # else:
+                    #     if log_enabled(ERROR):
+                    #         log(ERROR, 'unable to open socket for <%s>', self.connection)
+                    #     raise LDAPSocketOpenError('unable to open socket', exception_history)
+                    if log_enabled(ERROR):
+                        log(ERROR, 'unable to open socket for <%s>', self.connection)
+                    raise LDAPSocketOpenError('unable to open socket', exception_history)
                 elif not self.connection.server.current_address:
                     if log_enabled(ERROR):
                         log(ERROR, 'invalid server address for <%s>', self.connection)
@@ -150,7 +152,7 @@ class BaseStrategy(object):
 
             self.connection._deferred_open = False
             self._start_listen()
-            self.connection.do_auto_bind()
+            # self.connection.do_auto_bind()
             if log_enabled(NETWORK):
                 log(NETWORK, 'connection open for <%s>', self.connection)
 
@@ -190,31 +192,24 @@ class BaseStrategy(object):
         Tries to open and connect a socket to a Server
         raise LDAPExceptionError if unable to open or connect socket
         """
-        exc = None
         try:
             self.connection.socket = socket.socket(*address[:3])
         except Exception as e:
             self.connection.last_error = 'socket creation error: ' + str(e)
-            exc = e
-
-        if exc:
             if log_enabled(ERROR):
                 log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
-
-            raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
-
+            # raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+            raise communication_exception_factory(LDAPSocketOpenError, type(e)(str(e)))(self.connection.last_error)
         try:  # set socket timeout for opening connection
             if self.connection.server.connect_timeout:
                 self.connection.socket.settimeout(self.connection.server.connect_timeout)
             self.connection.socket.connect(address[4])
         except socket.error as e:
             self.connection.last_error = 'socket connection error while opening: ' + str(e)
-            exc = e
-
-        if exc:
             if log_enabled(ERROR):
                 log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
-            raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+            # raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+            raise communication_exception_factory(LDAPSocketOpenError, type(e)(str(e)))(self.connection.last_error)
 
         # Set connection recv timeout (must be set after connect,
         # because socket.settimeout() affects both, connect() as
@@ -230,12 +225,14 @@ class BaseStrategy(object):
                     self.connection.socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVTIMEO, pack('LL', self.connection.receive_timeout, 0))
             except socket.error as e:
                 self.connection.last_error = 'unable to set receive timeout for socket connection: ' + str(e)
-                exc = e
 
-        if exc:
-            if log_enabled(ERROR):
-                log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
-            raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+        # if exc:
+        #     if log_enabled(ERROR):
+        #         log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
+        #     raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+                if log_enabled(ERROR):
+                    log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
+                raise communication_exception_factory(LDAPSocketOpenError, type(e)(str(e)))(self.connection.last_error)
 
         if use_ssl:
             try:
@@ -244,13 +241,10 @@ class BaseStrategy(object):
                     self.connection._usage.wrapped_sockets += 1
             except Exception as e:
                 self.connection.last_error = 'socket ssl wrapping error: ' + str(e)
-                exc = e
-
-            if exc:
                 if log_enabled(ERROR):
                     log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
-                raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
-
+                # raise communication_exception_factory(LDAPSocketOpenError, exc)(self.connection.last_error)
+                raise communication_exception_factory(LDAPSocketOpenError, type(e)(str(e)))(self.connection.last_error)
         if self.connection.usage:
             self.connection._usage.open_sockets += 1
 
@@ -380,6 +374,7 @@ class BaseStrategy(object):
                 if log_enabled(PROTOCOL):
                     log(PROTOCOL, 'operation result <%s> for <%s>', result, self.connection)
                 self._outstanding.pop(message_id)
+                self.connection.result = result.copy()
                 raise LDAPOperationResult(result=result['result'], description=result['description'], dn=result['dn'], message=result['message'], response_type=result['type'])
 
             # checks if any response has a range tag
@@ -821,7 +816,6 @@ class BaseStrategy(object):
         return response, result
 
     def sending(self, ldap_message):
-        exc = None
         if log_enabled(NETWORK):
             log(NETWORK, 'sending 1 ldap message for <%s>', self.connection)
         try:
@@ -833,14 +827,11 @@ class BaseStrategy(object):
                 log(NETWORK, 'sent %d bytes via <%s>', len(encoded_message), self.connection)
         except socket.error as e:
             self.connection.last_error = 'socket sending error' + str(e)
-            exc = e
             encoded_message = None
-
-        if exc:
             if log_enabled(ERROR):
                 log(ERROR, '<%s> for <%s>', self.connection.last_error, self.connection)
-            raise communication_exception_factory(LDAPSocketSendError, exc)(self.connection.last_error)
-
+            # raise communication_exception_factory(LDAPSocketSendError, exc)(self.connection.last_error)
+            raise communication_exception_factory(LDAPSocketSendError, type(e)(str(e)))(self.connection.last_error)
         if self.connection.usage:
             self.connection._usage.update_transmitted_message(self.connection.request, len(encoded_message))
 
